@@ -39,6 +39,7 @@ import datetime
 import dxpy
 from dxpy import logger
 from dxpy.utils import merge
+from dxpy.utils.printing import fill
 
 NUM_CORES = multiprocessing.cpu_count()
 
@@ -363,12 +364,12 @@ def _update_version(app_name, version, app_spec, try_update=True):
             return None
         raise e
 
-def create_app(applet_id, applet_name, src_dir, publish=False, set_default=False, billTo=None, try_versions=None, try_update=True):
+def create_app(applet_id, applet_name, src_dir, publish=False, set_default=False, billTo=None, try_versions=None, try_update=True, confirm=True):
     """
     Creates a new app object from the specified applet.
     """
     app_spec = _get_app_spec(src_dir)
-    print >> sys.stderr, "Will create app with spec: ", app_spec
+    logger.info("Will create app with spec: %s" % (app_spec,))
 
     app_spec["applet"] = applet_id
     app_spec["name"] = applet_name
@@ -382,7 +383,7 @@ def create_app(applet_id, applet_name, src_dir, publish=False, set_default=False
         try_versions = [app_spec["version"]]
 
     for version in try_versions:
-        print >> sys.stderr, "Attempting to create version %s..." % (version,)
+        logger.debug("Attempting to create version %s..." % (version,))
         app_spec['version'] = version
         app_describe = None
         try:
@@ -407,23 +408,23 @@ def create_app(applet_id, applet_name, src_dir, publish=False, set_default=False
         # unnecessary API calls, but we always have to be prepared to recover
         # from API errors.
         if app_describe is None:
-            print >> sys.stderr, 'App %s/%s does not yet exist' % (app_spec["name"], version)
+            logger.debug('App %s/%s does not yet exist' % (app_spec["name"], version))
             app_id = _create_or_update_version(app_spec['name'], app_spec['version'], app_spec, try_update=try_update)
             if app_id is None:
                 continue
-            print >> sys.stderr, "Created app " + app_id
+            logger.info("Created app " + app_id)
             # Success!
             break
         elif app_describe.get("published", 0) == 0:
-            print >> sys.stderr, 'App %s/%s already exists and has not been published' % (app_spec["name"], version)
+            logger.debug('App %s/%s already exists and has not been published' % (app_spec["name"], version))
             app_id = _update_version(app_spec['name'], app_spec['version'], app_spec, try_update=try_update)
             if app_id is None:
                 continue
-            print >> sys.stderr, "Updated existing app " + app_id
+            logger.info("Updated existing app " + app_id)
             # Success!
             break
         else:
-            print >> sys.stderr, 'App %s/%s already exists and has been published' % (app_spec["name"], version)
+            logger.debug('App %s/%s already exists and has been published' % (app_spec["name"], version))
             # App has already been published. Give up on this version.
             continue
     else:
@@ -446,15 +447,48 @@ def create_app(applet_id, applet_name, src_dir, publish=False, set_default=False
 
     # Set authorizedUsers list appropriately, but only if provided.
     authorized_users_to_set = app_spec.get("authorizedUsers")
+    existing_authorized_users = dxpy.api.app_list_authorized_users(app_id)['authorizedUsers']
     if authorized_users_to_set is not None:
-        existing_authorized_users = dxpy.api.app_list_authorized_users(app_id)['authorizedUsers']
         authorized_users_to_add = set(authorized_users_to_set) - set(existing_authorized_users)
         authorized_users_to_remove = set(existing_authorized_users) - set(authorized_users_to_set)
+
+        skip_adding_public = False
+        if 'PUBLIC' in authorized_users_to_add:
+            acl_change_message = 'app-%s will be made public. Anyone will be able to view and run all published versions of this app.' % (app_spec['name'],)
+            if confirm:
+                if sys.stdout.isatty():
+                    try:
+                        print '***'
+                        print fill('WARNING: ' + acl_change_message)
+                        print '***'
+                        value = raw_input('Confirm making this app public [y/N]: ')
+                    except KeyboardInterrupt:
+                        value = 'n'
+                    if not value.lower().startswith('y'):
+                        skip_adding_public = True
+                else:
+                    # Default to NOT adding PUBLIC if operating
+                    # without a TTY.
+                    skip_adding_public = True
+            else:
+                logger.warn(acl_change_message)
+
+        if skip_adding_public:
+            authorized_users_to_add -= set(['PUBLIC'])
         if authorized_users_to_add:
             dxpy.api.app_add_authorized_users(app_id, input_params={'authorizedUsers': list(authorized_users_to_add)})
+        if skip_adding_public:
+            logger.warn('the app was NOT made public as requested in the dxapp.json. To make it so, run "dx add users app-%s PUBLIC".' % (app_spec["name"],))
+
         if authorized_users_to_remove:
             dxpy.api.app_remove_authorized_users(app_id, input_params={'authorizedUsers': list(authorized_users_to_remove)})
 
+    elif not len(existing_authorized_users):
+        # Apps created before the default ACL transition (and have
+        # 'PUBLIC' in their ACL), or apps that had authorized users
+        # added by any other means, will not have this message printed.
+        logger.warn('authorizedUsers is missing from the dxapp.json. No one will be able to view or run the app except the app\'s developers.')
+
     if publish:
         dxpy.api.app_publish(app_id, input_params={'makeDefault': set_default})
     else:
