@@ -217,6 +217,47 @@ class DXJob(DXObject):
         self._desc = dxpy.api.job_describe(self._dxid, describe_input, **kwargs)
         return self._desc
 
+    def add_tags(self, tags, **kwargs):
+        """
+        :param tags: Tags to add to the job
+        :type tags: list of strings
+
+        Adds each of the specified tags to the job. Takes no
+        action for tags that are already listed for the job.
+
+        """
+
+        dxpy.api.job_add_tags(self._dxid, {"tags": tags}, **kwargs)
+
+    def remove_tags(self, tags, **kwargs):
+        """
+        :param tags: Tags to remove from the job
+        :type tags: list of strings
+
+        Removes each of the specified tags from the job. Takes
+        no action for tags that the job does not currently have.
+
+        """
+
+        dxpy.api.job_remove_tags(self._dxid, {"tags": tags}, **kwargs)
+
+    def set_properties(self, properties, **kwargs):
+        """
+        :param properties: Property names and values given as key-value pairs of strings
+        :type properties: dict
+
+        Given key-value pairs in *properties* for property names and
+        values, the properties are set on the job for the given
+        property names. Any property with a value of :const:`None`
+        indicates the property will be deleted.
+
+        .. note:: Any existing properties not mentioned in *properties*
+           are not modified by this method.
+
+        """
+
+        dxpy.api.job_set_properties(self._dxid, {"properties": properties}, **kwargs)
+
     def wait_on_done(self, interval=2, timeout=sys.maxint, **kwargs):
         '''
         :param interval: Number of seconds between queries to the job's state
